@@ -26,7 +26,7 @@ from ctproc.utils import alias_map, print_crit, filter_words, DONT_ALIAS
 
 logging.basicConfig()
 logger = logging.getLogger(__file__)
-logger.setLevel('INFO')
+logger.setLevel('WARNING')
 
 
 
@@ -83,6 +83,7 @@ class CTProc:
     with ZipFile(self.config.zip_data, 'r') as zip_reader:
       with open(self.config.write_file, "w") as outfile:
         for i, ct_file in enumerate(tqdm(zip_reader.namelist())):
+
           if not self.iter_check(i):
             continue 
 
@@ -98,6 +99,10 @@ class CTProc:
 
           yield result_doc
 
+
+
+
+
   #----------------------------------------------------------------------------------------------------#
   # methods for building docs per config from ct_file and current iterator, with all combined checks
   #----------------------------------------------------------------------------------------------------#
@@ -634,11 +639,6 @@ class CTProc:
 
 
 
-
-
-
-
-
 if __name__ == "__main__":
     import argparse
 
